@@ -424,7 +424,7 @@ gnc_plugin_menu_additions_add_to_window (GncPlugin *plugin,
     per_window.window = window;
     per_window.ui_manager = window->ui_merge;
     per_window.group = gtk_action_group_new ("MenuAdditions" );
-    gtk_action_group_set_translation_domain (per_window.group, GETTEXT_PACKAGE);
+    gtk_action_group_set_translation_domain (per_window.group, PROJECT_NAME);
     per_window.merge_id = gtk_ui_manager_new_merge_id(window->ui_merge);
     gtk_ui_manager_insert_action_group(window->ui_merge, per_window.group, 0);
 
