@@ -58,7 +58,7 @@ typedef struct GncTreeViewPricePrivate
 } GncTreeViewPricePrivate;
 
 #define GNC_TREE_VIEW_PRICE_GET_PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_TREE_VIEW_PRICE, GncTreeViewPricePrivate))
+   ((GncTreeViewPricePrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_TREE_VIEW_PRICE))
 
 
 /************************************************************/
@@ -67,33 +67,7 @@ typedef struct GncTreeViewPricePrivate
 
 static GObjectClass *parent_class = NULL;
 
-GType
-gnc_tree_view_price_get_type (void)
-{
-    static GType gnc_tree_view_price_type = 0;
-
-    if (gnc_tree_view_price_type == 0)
-    {
-        static const GTypeInfo our_info =
-        {
-            sizeof (GncTreeViewPriceClass),
-            NULL,
-            NULL,
-            (GClassInitFunc) gnc_tree_view_price_class_init,
-            NULL,
-            NULL,
-            sizeof (GncTreeViewPrice),
-            0,
-            (GInstanceInitFunc) gnc_tree_view_price_init
-        };
-
-        gnc_tree_view_price_type = g_type_register_static (GNC_TYPE_TREE_VIEW,
-                                   "GncTreeViewPrice",
-                                   &our_info, 0);
-    }
-
-    return gnc_tree_view_price_type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(GncTreeViewPrice, gnc_tree_view_price, GNC_TYPE_TREE_VIEW)
 
 static void
 gnc_tree_view_price_class_init (GncTreeViewPriceClass *klass)
@@ -111,8 +85,6 @@ gnc_tree_view_price_class_init (GncTreeViewPriceClass *klass)
 
     /* GtkWidget signals */
     widget_class->destroy = gnc_tree_view_price_destroy;
-
-    g_type_class_add_private(klass, sizeof(GncTreeViewPricePrivate));
 }
 
 static void
@@ -629,6 +601,11 @@ gnc_tree_view_price_set_filter (GncTreeViewPrice *view,
 
     s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
     f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
+
+    /* disconnect model from view */
+    g_object_ref (G_OBJECT(s_model));
+    gtk_tree_view_set_model (GTK_TREE_VIEW(view), NULL);
+
     gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (f_model),
                                             gnc_tree_view_price_filter_helper,
                                             fd,
@@ -641,6 +618,11 @@ gnc_tree_view_price_set_filter (GncTreeViewPrice *view,
      * prices in the price database.  Once the very first price has been
      * added this error message goes away. */
     gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (f_model));
+
+    /* connect model to view */
+    gtk_tree_view_set_model (GTK_TREE_VIEW(view), s_model);
+    g_object_unref (G_OBJECT(s_model));
+
     LEAVE(" ");
 }
 
@@ -784,7 +766,7 @@ get_selected_prices_helper (GtkTreeModel *s_model,
 }
 
 /*
- * Given an price tree view, return a list of the selected commodities. The
+ * Given a price tree view, return a list of the selected prices. The
  * price tree must be in multiple selection mode.
  *
  * Note: It is the responsibility of the caller to free the returned
@@ -800,3 +782,47 @@ gnc_tree_view_price_get_selected_prices (GncTreeViewPrice *view)
     gtk_tree_selection_selected_foreach(selection, get_selected_prices_helper, &return_list);
     return return_list;
 }
+
+static void
+get_selected_commodity_helper (GtkTreeModel *s_model,
+                               GtkTreePath *s_path,
+                               GtkTreeIter *s_iter,
+                               gpointer data)
+{
+    GList **return_list = data;
+    GtkTreeModel *model, *f_model;
+    GtkTreeIter iter, f_iter;
+    gnc_commodity *commodity;
+
+    gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (s_model),
+            &f_iter, s_iter);
+
+    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
+    gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (f_model),
+            &iter, &f_iter);
+
+    model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(f_model));
+    commodity = gnc_tree_model_price_get_commodity (GNC_TREE_MODEL_PRICE(model), &iter);
+
+    if (commodity)
+        *return_list = g_list_append(*return_list, commodity);
+}
+
+/*
+ * Given a price tree view, return a list of the selected rows that have
+ * commodities but are not prices, the parent rows for prices. The
+ * price tree must be in multiple selection mode.
+ *
+ * Note: It is the responsibility of the caller to free the returned
+ * list.
+ */
+GList *
+gnc_tree_view_price_get_selected_commodities (GncTreeViewPrice *view)
+{
+    GtkTreeSelection *selection;
+    GList *return_list = NULL;
+
+    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(view));
+    gtk_tree_selection_selected_foreach (selection, get_selected_commodity_helper, &return_list);
+    return return_list;
+}
