@@ -1,5 +1,5 @@
 /********************************************************************\
- * assistant-acct-period.c - accouting period assistant for GnuCash *
+ * assistant-acct-period.c - accounting period assistant for GnuCash*
  * Copyright (C) 2001 Gnumatic, Inc.                                *
  * Copyright (C) 2001 Dave Peticolas <dave@krondo.com>              *
  * Copyright (C) 2003 Linas Vepstas <linas@linas.org>               *
@@ -365,7 +365,7 @@ ap_assistant_book_prepare (GtkAssistant *assistant, gpointer user_data)
     /* Display the book info */
 
     period_text =
-	/* Translators: Run the assistent in your language to see GTK's translation of the button labels. */
+	/* Translators: Run the assistant in your language to see GTK's translation of the button labels. */
         _("You have asked for a book to be created. This book "
           "will contain all transactions up to midnight %s "
           "(for a total of %d transactions spread over %d accounts).\n\n "
@@ -586,8 +586,8 @@ ap_assistant_create (AcctPeriodInfo *info)
                             gnc_frequency_new_from_recurrence(info->period, &info->closing_date));
 
     /* Change the text so that its more mainingful for this assistant */
-    gnc_frequency_set_frequency_label_text(info->period_menu, _("Period:"));
-    gnc_frequency_set_date_label_text(info->period_menu, _("Closing Date:"));
+    gnc_frequency_set_frequency_label_text(info->period_menu, _("Period"));
+    gnc_frequency_set_date_label_text(info->period_menu, _("Closing Date"));
 
     /* Reparent to the correct location */
 
