@@ -49,8 +49,6 @@ static void gnc_search_owner_class_init (GNCSearchOwnerClass *klass);
 static void gnc_search_owner_init   (GNCSearchOwner *gspaper);
 static void gnc_search_owner_finalize   (GObject *obj);
 
-typedef struct _GNCSearchOwnerPrivate GNCSearchOwnerPrivate;
-
 typedef struct _GNCSearchOwnerPrivate
 {
     GncOwner    owner;
@@ -59,8 +57,10 @@ typedef struct _GNCSearchOwnerPrivate
     GtkWidget * owner_choice;
 } GNCSearchOwnerPrivate;
 
+G_DEFINE_TYPE_WITH_PRIVATE(GNCSearchOwner, gnc_search_owner, GNC_TYPE_SEARCH_CORE_TYPE);
+
 #define _PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_SEARCH_OWNER, GNCSearchOwnerPrivate))
+   ((GNCSearchOwnerPrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_SEARCH_OWNER))
 
 static GNCSearchCoreTypeClass *parent_class;
 
@@ -73,34 +73,6 @@ enum
 static guint signals[LAST_SIGNAL] = { 0 };
 #endif
 
-GType
-gnc_search_owner_get_type (void)
-{
-    static GType type = 0;
-
-    if (!type)
-    {
-        GTypeInfo type_info =
-        {
-            sizeof(GNCSearchOwnerClass),    /* class_size */
-            NULL,                           /* base_init */
-            NULL,                           /* base_finalize */
-            (GClassInitFunc)gnc_search_owner_class_init,
-            NULL,                           /* class_finalize */
-            NULL,                           /* class_data */
-            sizeof(GNCSearchOwner),         /* */
-            0,                              /* n_preallocs */
-            (GInstanceInitFunc)gnc_search_owner_init,
-        };
-
-        type = g_type_register_static (GNC_TYPE_SEARCH_CORE_TYPE,
-                                       "GNCSearchOwner",
-                                       &type_info, 0);
-    }
-
-    return type;
-}
-
 static void
 gnc_search_owner_class_init (GNCSearchOwnerClass *klass)
 {
@@ -118,8 +90,6 @@ gnc_search_owner_class_init (GNCSearchOwnerClass *klass)
     gnc_search_core_type->get_widget = gncs_get_widget;
     gnc_search_core_type->get_predicate = gncs_get_predicate;
     gnc_search_core_type->clone = gncs_clone;
-
-    g_type_class_add_private(klass, sizeof(GNCSearchOwnerPrivate));
 }
 
 static void
