@@ -1705,7 +1705,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
 
         action_group = gtk_action_group_new ("ReconcileWindowActions");
         recnData->action_group = action_group;
-        gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+        gtk_action_group_set_translation_domain (action_group, PROJECT_NAME);
         gtk_action_group_add_actions (action_group, recnWindow2_actions,
                                       recnWindow2_n_actions, recnData);
         action =
