@@ -124,7 +124,6 @@ static gboolean gnc_gen_trans_onButtonPressed_cb (
                     GNCImportMainMatcher *info);
 static gboolean gnc_gen_trans_onPopupMenu_cb (
                     GtkTreeView *treeview,
-                    GdkEvent *event,
                     GNCImportMainMatcher *info);
 static void refresh_model_row (
                     GNCImportMainMatcher *gui,
@@ -178,6 +177,21 @@ void gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
     g_free (info);
 }
 
+gboolean gnc_gen_trans_list_empty(GNCImportMainMatcher *info)
+{
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    GNCImportTransInfo *trans_info;
+    g_assert (info);
+    model = gtk_tree_view_get_model (info->view);
+    return !gtk_tree_model_get_iter_first (model, &iter);
+}
+
+void gnc_gen_trans_list_show_all(GNCImportMainMatcher *info)
+{
+    gtk_widget_show_all (GTK_WIDGET (info->main_widget));
+}
+
 void
 on_matcher_ok_clicked (GtkButton *button, GNCImportMainMatcher *info)
 {
@@ -191,7 +205,11 @@ on_matcher_ok_clicked (GtkButton *button, GNCImportMainMatcher *info)
 
     model = gtk_tree_view_get_model (info->view);
     if (!gtk_tree_model_get_iter_first (model, &iter))
+    {
+        // No transaction, we can just close the dialog.
+        gnc_gen_trans_list_delete (info);
         return;
+    }
 
     /* Don't run any queries and/or split sorts while processing the matcher
     results. */
@@ -651,7 +669,6 @@ gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
 
 static gboolean
 gnc_gen_trans_onPopupMenu_cb (GtkTreeView *treeview,
-                              GdkEvent *event,
                               GNCImportMainMatcher *info)
 {
     GtkTreeSelection *selection;
@@ -746,8 +763,7 @@ gnc_gen_trans_init_view (GNCImportMainMatcher *info,
     /* prevent the rows being dragged to a different order */
     gtk_tree_view_set_reorderable (view, FALSE);
 
-    /* Add the columns *
-     * (keep the line break below to avoid a translator comment) */
+    /* Add the columns */
     add_text_column (view, _("Date"), DOWNLOADED_COL_DATE_TXT);
     info->account_column = add_text_column (view, _("Account"), DOWNLOADED_COL_ACCOUNT);
     gtk_tree_view_column_set_visible (info->account_column, show_account);
@@ -896,7 +912,8 @@ show_account_column_toggled_cb (GtkToggleButton *togglebutton,
 GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
         const gchar* heading,
         gboolean all_from_same_account,
-        gint match_date_hardlimit)
+        gint match_date_hardlimit,
+        gboolean show_all)
 {
     GNCImportMainMatcher *info;
     GtkBuilder *builder;
@@ -951,7 +968,8 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
         gtk_label_set_text (GTK_LABEL (heading_label), heading);
 
     gnc_restore_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->main_widget), GTK_WINDOW (parent));
-    gtk_widget_show_all (GTK_WIDGET (info->main_widget));
+    if(show_all)
+        gtk_widget_show_all (GTK_WIDGET (info->main_widget));
 
     info->transaction_processed_cb = NULL;
 
