@@ -29,6 +29,7 @@
 
 (use-modules (srfi srfi-1))
 (use-modules (srfi srfi-11))            ;let-values
+(use-modules (ice-9 match))
 (use-modules (gnucash utilities))
 (use-modules (gnucash gnc-module))
 (use-modules (gnucash gettext))
@@ -39,6 +40,7 @@
 (use-modules (gnucash report business-reports))
 
 (define optname-to-date (N_ "To"))
+(define optname-sort-by (N_ "Sort By"))
 (define optname-sort-order (N_ "Sort Order"))
 (define optname-report-currency (N_ "Report's currency"))
 (define optname-price-source (N_ "Price Source"))
@@ -90,6 +92,20 @@ exist but have no suitable transactions."))
      (gnc:lookup-option options gnc:pagename-general optname-to-date)
      (cons 'relative 'today))
 
+    (add-option
+     (gnc:make-multichoice-option
+      gnc:pagename-general optname-sort-by "i" (N_ "Sort companies by.") 'name
+      (list
+       (vector 'name
+               (N_ "Name")
+               (N_ "Name of the company."))
+       (vector 'total
+               (N_ "Total Owed")
+               (N_ "Total amount owed to/from Company."))
+       (vector 'oldest-bracket
+               (N_ "Bracket Total Owed")
+               (N_ "Amount owed in oldest bracket - if same go to next oldest.")))))
+
     (add-option
      (gnc:make-multichoice-option
       gnc:pagename-general optname-sort-order "ia" (N_ "Sort order.") 'increasing
@@ -152,24 +168,26 @@ exist but have no suitable transactions."))
     (fold-right (lambda (opt elt prev) (if opt (cons elt prev) prev))
                 '() address-list-options result-list)))
 
-(define (txn-is-invoice? txn)
-  (eqv? (xaccTransGetTxnType txn) TXN-TYPE-INVOICE))
-
-(define (txn-is-payment? txn)
-  (eqv? (xaccTransGetTxnType txn) TXN-TYPE-PAYMENT))
+(define (split-is-not-business? split)
+  (let ((type (xaccTransGetTxnType (xaccSplitGetParent split))))
+    (not (or (eqv? type TXN-TYPE-INVOICE)
+             (eqv? type TXN-TYPE-PAYMENT)))))
 
 (define (gnc-owner-equal? a b)
   (string=? (gncOwnerReturnGUID a) (gncOwnerReturnGUID b)))
 
-(define (account<? a b)
-  (< (xaccAccountOrder a b) 0))
-
 (define (split-has-owner? split owner)
   (let* ((split-owner (split->owner split))
          (retval (gnc-owner-equal? split-owner owner)))
     (gncOwnerFree split-owner)
     retval))
 
+(define (split-owner-is-invalid? split)
+  (let* ((owner (split->owner split))
+         (retval (not (gncOwnerIsValid owner))))
+    (gncOwnerFree owner)
+    retval))
+
 (define (split-from-acct? split acct)
   (equal? acct (xaccSplitGetAccount split)))
 
@@ -180,7 +198,7 @@ exist but have no suitable transactions."))
 ;; simpler version of gnc:owner-from-split. must be gncOwnerFree after
 ;; use! see split-has-owner? above...
 (define (split->owner split)
-  (let* ((lot (xaccSplitGetLot (gnc-lot-get-earliest-split (xaccSplitGetLot split))))
+  (let* ((lot (xaccSplitGetLot split))
          (owner (gncOwnerNew))
          (use-lot-owner? (gncOwnerGetOwnerFromLot lot owner)))
     (unless use-lot-owner?
@@ -196,7 +214,7 @@ exist but have no suitable transactions."))
 
   (define make-heading-list
     (list (_ "Company")
-          (_ "Prepayments")
+          (_ "Pre-Payment")
           (_ "Current")
           (_ "0-30 days")
           (_ "31-60 days")
@@ -213,20 +231,27 @@ exist but have no suitable transactions."))
                        (gnc:date-option-absolute-time
                         (op-value gnc:pagename-general optname-to-date))))
          (sort-order (op-value gnc:pagename-general optname-sort-order))
+         (sort-by (op-value gnc:pagename-general optname-sort-by))
          (show-zeros (op-value gnc:pagename-general optname-show-zeros))
          (date-type (op-value gnc:pagename-general optname-date-driver))
          (query (qof-query-create-for-splits))
-         (invalid-splits '())
          (document (gnc:make-html-document)))
 
-    ;; for sorting and delete-duplicates. compare GUIDs
-    (define (ownerGUID<? a b)
-      (string<? (gncOwnerGetGUID a) (gncOwnerGetGUID b)))
-
-    ;; for presentation. compare names.
-    (define (owner<? a b)
-      ((if (eq? sort-order 'increasing) string<? string>?)
-       (gncOwnerGetName a) (gncOwnerGetName b)))
+    (define (sort-aging<? a b)
+      (match-let* (((own1 aging1 aging-total1) a)
+                   ((own2 aging2 aging-total2) b)
+                   (increasing? (eq? sort-order 'increasing))
+                   (op-str (if increasing? string<? string>?))
+                   (op-num (if increasing? < >)))
+        (case sort-by
+          ((name)  (op-str (gncOwnerGetName own1) (gncOwnerGetName own2)))
+          ((total) (op-num aging-total1 aging-total2))
+          (else
+           (let lp ((aging1 aging1) (aging2 aging2))
+             (cond
+              ((null? aging1) (op-str (gncOwnerGetName own1) (gncOwnerGetName own2)))
+              ((= (car aging1) (car aging2)) (lp (cdr aging1) (cdr aging2)))
+              (else (op-num (car aging1) (car aging2)))))))))
 
     ;; set default title
     (gnc:html-document-set-title! document report-title)
@@ -238,19 +263,14 @@ exist but have no suitable transactions."))
 
      (else
       (setup-query query accounts report-date)
-      (let* ((splits (xaccQueryGetSplitsUniqueTrans query))
-             (accounts (sort-and-delete-duplicates (map xaccSplitGetAccount splits)
-                                                   account<? equal?)))
+      (let* ((splits (xaccQueryGetSplitsUniqueTrans query)))
         (qof-query-destroy query)
 
         ;; loop into each APAR account
         (let loop ((accounts accounts)
-                   (splits (filter
-                            (lambda (split)
-                              (or (txn-is-invoice? (xaccSplitGetParent split))
-                                  (txn-is-payment? (xaccSplitGetParent split))))
-                            splits))
+                   (splits splits)
                    (accounts-and-owners '())
+                   (invalid-splits '())
                    (tofree '()))
           (cond
            ((null? accounts)
@@ -313,7 +333,7 @@ exist but have no suitable transactions."))
                                 (gnc:owner-report-text owner account)
                                 (gnc:make-gnc-monetary comm aging-total)))))
                             (options->address options receivable owner)))))
-                      (reverse owners-and-aging))
+                      (sort owners-and-aging sort-aging<?))
 
                      (gnc:html-table-append-row!
                       table
@@ -349,62 +369,60 @@ exist but have no suitable transactions."))
 
            (else
             (let* ((account (car accounts))
-                   (splits-acc-others (list-split splits split-from-acct? account))
-                   (acc-splits (car splits-acc-others))
-                   (other-acc-splits (cdr splits-acc-others))
-                   (split-owners
-                    (fold
-                     (lambda (a b)
-                       (let ((owner (split->owner a)))
-                         (cond
-                          ((gncOwnerIsValid owner) (cons owner b))
-                          ;; some payment splits may have no owner in
-                          ;; this account. skip. see bug 797506.
-                          (else
-                           (gnc:warn "split " (gnc:strify a) " has no owner")
-                           (set! invalid-splits
-                             (cons (list (_ "Payment has no owner") a)
-                                   invalid-splits))
-                           (gncOwnerFree owner)
-                           b))))
-                     '() acc-splits))
-                   (acc-owners (sort (sort-and-delete-duplicates
-                                      split-owners ownerGUID<? gnc-owner-equal?)
-                                     owner<?)))
+                   (splits-acc-others (list-split splits split-from-acct? account)))
 
-              ;; loop into each APAR account split
-              (let lp ((acc-owners acc-owners)
-                       (acc-splits acc-splits)
+              (let lp ((acc-splits (car splits-acc-others))
                        (acc-totals (make-list (1+ num-buckets) 0))
+                       (invalid-splits invalid-splits)
+                       (tofree tofree)
                        (owners-and-aging '()))
-                (cond
-                 ((null? acc-owners)
-                  (loop (cdr accounts)
-                        other-acc-splits
-                        (if (null? owners-and-aging)
-                            accounts-and-owners
-                            (cons (list account owners-and-aging acc-totals)
-                                  accounts-and-owners))
-                        (append-reverse tofree split-owners)))
 
-                 (else
-                  (let* ((owner (car acc-owners))
-                         (splits-own-others (list-split acc-splits split-has-owner?
-                                                        owner))
-                         (owner-splits (car splits-own-others))
-                         (other-owner-splits (cdr splits-own-others))
-                         (aging (gnc:owner-splits->aging-list
-                                 owner-splits num-buckets report-date
-                                 date-type receivable))
-                         (aging-total (apply + aging)))
-                    (lp (cdr acc-owners)
-                        other-owner-splits
-                        (map + acc-totals
-                             (reverse (cons aging-total aging)))
-                        (if (or show-zeros (not (every zero? aging)))
-                            (cons (list owner aging aging-total)
-                                  owners-and-aging)
-                            owners-and-aging)))))))))))))
+                (match acc-splits
+                  (()
+                   (loop (cdr accounts)
+                         (cdr splits-acc-others)
+                         (if (null? owners-and-aging)
+                             accounts-and-owners
+                             (cons (list account owners-and-aging acc-totals)
+                                   accounts-and-owners))
+                         invalid-splits
+                         tofree))
+
+                  ;; txn type != TXN_TYPE_INVOICE or TXN_TYPE_PAYMENT.
+                  (((? split-is-not-business? this) . rest)
+                   (let ((type (xaccTransGetTxnType (xaccSplitGetParent this))))
+                     (lp rest
+                         acc-totals
+                         (cons (list (format #f (_ "Invalid Txn Type ~a") type) this)
+                               invalid-splits)
+                         tofree
+                         owners-and-aging)))
+
+                  ;; some payment splits may have no owner in this
+                  ;; account. skip. see bug 797506.
+                  (((? split-owner-is-invalid? this) . rest)
+                   (gnc:warn "split " this " has no owner")
+                   (lp rest
+                       acc-totals
+                       (cons (list (_ "Payment has no owner") this) invalid-splits)
+                       tofree
+                       owners-and-aging))
+
+                  ((this . _)
+                   (match-let* ((owner (split->owner this))
+                                ((owner-splits . other-owner-splits)
+                                 (list-split acc-splits split-has-owner? owner))
+                                (aging (gnc:owner-splits->aging-list
+                                        owner-splits num-buckets report-date
+                                        date-type receivable))
+                                (aging-total (apply + aging)))
+                     (lp other-owner-splits
+                         (map + acc-totals (reverse (cons aging-total aging)))
+                         invalid-splits
+                         (cons owner tofree)
+                         (if (or show-zeros (any (negate zero?) aging))
+                             (cons (list owner aging aging-total) owners-and-aging)
+                             owners-and-aging)))))))))))))
     (gnc:report-finished)
     document))
 
