@@ -309,18 +309,19 @@ gnc_price_create (QofBook *book)
 
     g_return_val_if_fail (book, NULL);
 
+    ENTER(" ");
     p = g_object_new(GNC_TYPE_PRICE, NULL);
 
     qof_instance_init_data (&p->inst, GNC_ID_PRICE, book);
     qof_event_gen (&p->inst, QOF_EVENT_CREATE, NULL);
-
+    LEAVE ("price created %p", p);
     return p;
 }
 
 static void
 gnc_price_destroy (GNCPrice *p)
 {
-    ENTER(" ");
+    ENTER("destroy price %p", p);
     qof_event_gen (&p->inst, QOF_EVENT_DESTROY, NULL);
 
     if (p->type) CACHE_REMOVE(p->type);
@@ -372,14 +373,14 @@ gnc_price_clone (GNCPrice* p, QofBook *book)
 
     if (!p)
     {
-        LEAVE (" ");
+        LEAVE ("return NULL");
         return NULL;
     }
 
     new_p = gnc_price_create(book);
     if (!new_p)
     {
-        LEAVE (" ");
+        LEAVE ("return NULL");
         return NULL;
     }
 
@@ -394,7 +395,7 @@ gnc_price_clone (GNCPrice* p, QofBook *book)
     gnc_price_set_value(new_p, gnc_price_get_value(p));
     gnc_price_set_currency(new_p, gnc_price_get_currency(p));
     gnc_price_commit_edit(new_p);
-    LEAVE (" ");
+    LEAVE ("return cloned price %p", new_p);
     return(new_p);
 }
 
@@ -838,6 +839,7 @@ QOF_GOBJECT_IMPL(gnc_pricedb, GNCPriceDB, QOF_TYPE_INSTANCE);
 static void
 gnc_pricedb_init(GNCPriceDB* pdb)
 {
+    pdb->reset_nth_price_cache = FALSE;
 }
 
 static void
@@ -1801,7 +1803,7 @@ GNCPrice *gnc_pricedb_lookup_latest(GNCPriceDB *db,
     result = price_list->data;
     gnc_price_ref(result);
     g_list_free (price_list);
-    LEAVE(" ");
+    LEAVE("price is %p", result);
     return result;
 }
 
@@ -2160,93 +2162,84 @@ gnc_pricedb_num_prices(GNCPriceDB *db,
     return result;
 }
 
-/* Return the nth price for the given commodity
+/* Helper function for combining the price lists in gnc_pricedb_nth_price. */
+static void
+list_combine (gpointer element, gpointer data)
+{
+    GList *list = *(GList**)data;
+    if (list == NULL)
+        *(GList**)data = g_list_copy (element);
+    else
+    {
+        GList *new_list = g_list_concat ((GList *)list, g_list_copy (element));
+        *(GList**)data = new_list;
+    }
+}
+
+/* This function is used by gnc-tree-model-price.c for iterating through the
+ * prices when building or filtering the pricedb dialog's
+ * GtkTreeView. gtk-tree-view-price.c sorts the results after it has obtained
+ * the values so there's nothing gained by sorting. However, for very large
+ * collections of prices in multiple currencies (here commodity is the one being
+ * priced and currency the one in which the price is denominated; note that they
+ * may both be currencies or not) just concatenating the price lists together
+ * can be expensive because the recieving list must be traversed to obtain its
+ * end. To avoid that cost n times we cache the commodity and merged price list.
+ * Since this is a GUI-driven function there is no concern about concurrency.
  */
+
 GNCPrice *
 gnc_pricedb_nth_price (GNCPriceDB *db,
                        const gnc_commodity *c,
                        const int n)
 {
+    static const gnc_commodity *last_c = NULL;
+    static GList *prices = NULL;
+
     GNCPrice *result = NULL;
     GHashTable *currency_hash;
+    g_return_val_if_fail (GNC_IS_COMMODITY (c), NULL);
 
     if (!db || !c || n < 0) return NULL;
-    ENTER ("db=%p commodity=%p index=%d", db, c, n);
+    ENTER ("db=%p commodity=%s index=%d", db, gnc_commodity_get_mnemonic(c), n);
 
-    currency_hash = g_hash_table_lookup(db->commodity_hash, c);
+    if (last_c && prices && last_c == c && db->reset_nth_price_cache == FALSE)
+    {
+        result = g_list_nth_data (prices, n);
+        LEAVE ("price=%p", result);
+        return result;
+    }
+
+    last_c = c;
+
+    if (prices)
+    {
+        g_list_free (prices);
+        prices = NULL;
+    }
+
+    db->reset_nth_price_cache = FALSE;
+
+    currency_hash = g_hash_table_lookup (db->commodity_hash, c);
     if (currency_hash)
     {
-        int num_currencies = g_hash_table_size(currency_hash);
-        if (num_currencies == 1)
-        {
-            /* Optimize the case of prices in only one currency, it's common
-               and much faster */
-            GHashTableIter iter;
-            gpointer key, value;
-            g_hash_table_iter_init(&iter, currency_hash);
-            if (g_hash_table_iter_next(&iter, &key, &value))
-            {
-                PriceList *prices = value;
-                result = g_list_nth_data(prices, n);
-            }
-        }
-        else if (num_currencies > 1)
-        {
-            /* Prices for multiple currencies, must find the nth entry in the
-               merged currency list. */
-            GList **price_array = (GList **)g_new(gpointer, num_currencies);
-            GList **next_list;
-            int i, j, k;
-            GHashTableIter iter;
-            gpointer key, value;
-
-            /* Build an array of all the currencies this commodity has prices for */
-            for (i = 0, g_hash_table_iter_init(&iter, currency_hash);
-                 g_hash_table_iter_next(&iter, &key, &value) && i < num_currencies;
-                 ++i)
-            {
-                price_array[i] = value;
-            }
-
-            /* Iterate up to n times (there are i prices, so going past i will run off the end of the array) to get the nth price, each time finding the currency
-               with the latest price */
-            for (k = 0; k < n && k < i; ++k)
-            {
-                next_list = NULL;
-                for (j = 0; j < i; ++j)
-                {
-                    /* Save this entry if it's the first one or later than
-                       the saved one. */
-                    if (price_array[k] != NULL &&
-                        (next_list == NULL || *next_list == NULL ||
-                        compare_prices_by_date((*next_list)->data, (price_array[j])->data) > 0))
-                    {
-                        next_list = &price_array[j];
-                    }
-                }
-                /* next_list points to the list with the latest price unless all
-                   the lists are empty */
-                if (next_list && *next_list)
-                {
-                    result = (*next_list)->data;
-                    *next_list = (*next_list)->next;
-                }
-                else
-                {
-                    /* all the lists are empty, "n" is greater than the number
-                       of prices for this commodity. */
-                    result = NULL;
-                    break;
-                }
-            }
-            g_free(price_array);
-        }
+        GList *currencies = g_hash_table_get_values (currency_hash);
+        g_list_foreach (currencies, list_combine, &prices);
+        result = g_list_nth_data (prices, n);
+        g_list_free (currencies);
     }
 
     LEAVE ("price=%p", result);
     return result;
 }
 
+void
+gnc_pricedb_nth_price_reset_cache (GNCPriceDB *db)
+{
+    if (db)
+        db->reset_nth_price_cache = TRUE;
+}
+
 GNCPrice *
 gnc_pricedb_lookup_day_t64(GNCPriceDB *db,
                            const gnc_commodity *c,
@@ -2277,6 +2270,7 @@ gnc_pricedb_lookup_at_time64(GNCPriceDB *db,
         {
             gnc_price_ref(p);
             g_list_free (price_list);
+            LEAVE("price is %p", p);
             return p;
         }
         item = item->next;
